@@ -3,26 +3,20 @@ import shutil
 import sys
 import time
 
-from rich.traceback import install
-
-from progress_table import ProgressTable
+from progress_table import ProgressTableV1
 
 shutil.get_terminal_size()
 
-install()
-
-
 # Define the columns at the beginning
-table = ProgressTable(
+table = ProgressTableV1(
     columns=["step", "x", "x squared"],
-
     # Default arguments:
     refresh_rate=10,
     num_decimal_places=4,
     default_column_width=8,
     default_column_alignment="center",
     print_row_on_update=True,
-    reprint_header_every_n_rows=30,
+    reprint_header_every_n_rows=10,
     custom_format=None,
     embedded_progress_bar=False,
     table_style="normal",
@@ -32,7 +26,7 @@ table.add_column("x", width=3)
 table.add_column("x root", color="red")
 table.add_column("random average", color=["bright", "red"], aggregate="mean")
 
-for step in range(10):
+for step in range(100):
     x = random.randint(0, 200)
 
     # There are two equivalent ways to add new values
@@ -40,8 +34,8 @@ for step in range(10):
     table["step"] = step
     table["x"] = x
     # Second:
-    table.update("x root", x ** 0.5)
-    table.update("x squared", x ** 2)
+    table.update("x root", x**0.5)
+    table.update("x squared", x**2)
 
     # Display the progress bar by wrapping the iterator
     for _ in table(10):
@@ -50,7 +44,12 @@ for step in range(10):
         time.sleep(0.1)
 
     # Go to the next row when you're ready
-    table.next_row()
+    if step % 5 == 0:
+        split = True
+    else:
+        split = False
+
+    table.next_row(split=split)
 
 # Close the table when it's ready
 table.close()
